@@ -1,4 +1,5 @@
 from functools import wraps
+import itertools
 
 import hashlib
 from urllib.parse import quote
@@ -99,11 +100,17 @@ def cache_memoize(
     def decorator(func):
         def _default_make_cache_key(*args, **kwargs):
             cache_key = ":".join(
-                [quote(str(x)) for x in args_rewrite(*args)]
-                + [quote("{}={}".format(k, v)) for k, v in kwargs.items()]
+                itertools.chain(
+                    (quote(str(x)) for x in args_rewrite(*args)),
+                    (
+                        "{}={}".format(quote(k), quote(str(v)))
+                        for k, v in sorted(kwargs.items())
+                    ),
+                )
             )
+            prefix_ = prefix or ".".join((func.__module__ or "", func.__qualname__))
             return hashlib.md5(
-                force_bytes("cache_memoize" + (prefix or func.__qualname__) + cache_key)
+                force_bytes("cache_memoize" + prefix_ + cache_key)
             ).hexdigest()
 
         _make_cache_key = key_generator_callable or _default_make_cache_key
